@@ -3,9 +3,11 @@
 pub mod lsa;
 pub mod query;
 pub mod send;
+mod sysfs;
 
+use crate::sysfs::*;
 use serde::{Deserialize, Serialize};
-use std::{fs, io, path::Path, path::PathBuf};
+use std::{fmt, fs, io, path::Path, path::PathBuf};
 
 /// Magic IOCTL number from the kernel.
 pub const CXL_IOC_MAGIC: u8 = 0xce;
@@ -25,6 +27,12 @@ pub struct Memdev {
     ram: u64,
 }
 
+impl fmt::Display for Memdev {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "{}", self.name)
+    }
+}
+
 impl Memdev {
     /// Returns a memory device for the given path
     pub fn new(path: &str) -> Option<Self> {
@@ -55,62 +63,6 @@ impl Memdev {
     }
 }
 
-/// Returns the contents of a sysfs node
-///
-/// # Arguments
-///
-///  * `path` - Top level directory of a CXL sysfs node.
-///  * `node` - Specific node without the directory @path.
-///
-/// # Examples
-///
-/// ```no_run
-/// let cxl_dev = "/sys/devices/pci0000:34/0000:34:00.0/0000:35:00.0/mem0";
-/// let fw_version: String = cxl_rs::get_sysfs_node(cxl_dev, "firmware_version").unwrap();
-/// ```
-pub fn get_sysfs_node(path: &str, node: &str) -> Result<String, std::io::Error> {
-    let f = Path::new(path).join(node);
-    Ok(fs::read_to_string(f)?.trim_end().to_string())
-}
-
-/// Returns the parsed hex value from a sysfs node.
-///
-/// # Arguments
-///
-///  * `path` - Top level directory of a CXL sysfs node.
-///  * `node` - Specific node without the directory @path.
-///
-/// # Examples
-///
-/// ```no_run
-/// # use std::io;
-/// let cxl_dev = "/sys/devices/pci0000:34/0000:34:00.0/0000:35:00.0/mem0";
-/// let pmem_size: u64 = cxl_rs::get_sysfs_node_hex(cxl_dev, "pmem/size")?;
-/// # Ok::<(), io::Error>(())
-/// ```
-pub fn get_sysfs_node_hex(path: &str, node: &str) -> Result<u64, std::io::Error> {
-    Ok(u64::from_str_radix(&get_sysfs_node(path, node)?[2..], 16).expect("Couldn't parse"))
-}
-
-/// Returns a u64 value from a sysfs node.
-///
-/// # Arguments
-///
-///  * `path` - Top level directory of a CXL sysfs node.
-///  * `node` - Specific node without the directory @path.
-///
-/// # Examples
-///
-/// ```no_run
-/// # use std::io;
-/// let cxl_dev = "/sys/devices/pci0000:34/0000:34:00.0/0000:35:00.0/mem0";
-/// let payload_size = cxl_rs::get_sysfs_node_u64(cxl_dev, "payload_size")?;
-/// # Ok::<(), io::Error>(())
-/// ```
-pub fn get_sysfs_node_u64(path: &str, node: &str) -> Result<u64, std::io::Error> {
-    Ok(get_sysfs_node(path, node)?.parse().expect("Couldn't parse"))
-}
-
 /// Returns CXL memory devices found in sysfs.
 ///
 /// # Arguments
@@ -126,7 +78,8 @@ pub fn get_sysfs_node_u64(path: &str, node: &str) -> Result<u64, std::io::Error>
 /// }
 /// ```
 pub fn get_sysfs_devices(path: Option<&Path>) -> io::Result<Vec<(String, PathBuf)>> {
-    let sysfs_dir = path.unwrap_or_else(|| Path::new("/sys/bus/cxl/devices/"));
+    let default = format!("{}/{}", CXL_SYSFS_BASE, "devices/");
+    let sysfs_dir = path.unwrap_or_else(|| Path::new(&default));
     let mut result = Vec::<(String, PathBuf)>::new();
 
     let files = fs::read_dir(sysfs_dir).unwrap();
